@@ -1,9 +1,9 @@
 #include "horizontalcall.h"
 #include "appsettingsmanager.h"
 #include "ui_horizontalcall.h"
-
 #include <QtMaemo5>
 #include <QtDBus>
+#include <QtDBus/QtDBus>
 
 using namespace QtMobility;
 
@@ -68,6 +68,10 @@ horizontalcall::horizontalcall(QWidget *parent) :
 
     m_scrollArea = NULL;
     m_FetchPending = true;
+
+    //DBus Related
+    //QDBusConnection::sessionBus().registerService(APP_DBUS_SERVICE);
+    //QDBusConnection::sessionBus().registerObject(APP_DBUS_PATH, this, QDBusConnection::ExportScriptableSlots);
 }
 
 void horizontalcall::ContactUpdatesDone()
@@ -387,6 +391,18 @@ void horizontalcall::resizeEvent(QResizeEvent *e)
     }*/
 }
 
+void horizontalcall::closeEvent(QCloseEvent *event)
+{
+    hide();
+    event->ignore();
+}
+
+int horizontalcall::top_application()
+{
+    show();
+    return 0;
+}
+
 void horizontalcall::AddContact(QContact temp)
 {
     qDebug() << "Main Thread : Got contact to update.";
@@ -394,6 +410,13 @@ void horizontalcall::AddContact(QContact temp)
     listWidgetFiltered->addItem(displayLabel.label());
     QStringList tempQStringList = displayLabel.label().split(" ", QString::SkipEmptyParts);
     tempQStringList.append(displayLabel.label());
+
+    /*QList<QContactPhoneNumber> allDetails = temp.details<QContactPhoneNumber>();
+
+    for (int i = 0; i < allDetails.size(); i++) {
+        tempQStringList.append(allDetails.at(i).number());
+    }*/
+
     m_NameStrings.append(tempQStringList);
 }
 
@@ -607,7 +630,7 @@ void horizontalcall::deleteLetters()
 
 void horizontalcall::exitButtonClicked()
 {
-    exit(0);
+    close();
 }
 
 void horizontalcall::scanContacts()
@@ -723,14 +746,62 @@ void horizontalcall::showContactDetails(int row)
 
 void horizontalcall::phoneNumberClicked()
 {
-    QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
-    m_CallButtons.append(tempButton);
-    QString temp = tempButton->text();
-    m_PhoneNumbers.append(new QString(tempButton->text()));
-    tempButton->setText("Dialing...");
-    QTimer::singleShot(1000, this, SLOT(enableButtons()));
-    tempButton->setEnabled(false);
-    makeDbusGSMCall(temp);
+    QMessageBox msgBox;
+    QPushButton *callButton = msgBox.addButton(tr("Call"), QMessageBox::YesRole);
+    QPushButton *smsButton = msgBox.addButton(tr("SMS"), QMessageBox::NoRole);
+
+    msgBox.exec();
+
+    if (msgBox.clickedButton() == callButton) {
+        qDebug() << "Main Thread : Call";
+        QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
+        m_CallButtons.append(tempButton);
+        QString temp = tempButton->text();
+        m_PhoneNumbers.append(new QString(tempButton->text()));
+        tempButton->setText("Dialing...");
+        QTimer::singleShot(1000, this, SLOT(enableButtons()));
+        tempButton->setEnabled(false);
+        makeDbusGSMCall(temp);
+        //sendFastSMS(temp);
+    } else if (msgBox.clickedButton() == smsButton) {
+        qDebug() << "Main Thread : SMS";
+        QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
+        m_CallButtons.append(tempButton);
+        QString temp = tempButton->text();
+        m_PhoneNumbers.append(new QString(tempButton->text()));
+        tempButton->setText("SMSing...");
+        QTimer::singleShot(1000, this, SLOT(enableButtons()));
+        tempButton->setEnabled(false);
+        //makeDbusGSMCall(temp);
+        sendFastSMS(temp);
+    }
+}
+
+void horizontalcall::sendFastSMS(QString number)
+{
+    qDebug() << "Sending SMS to : " << number;
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "it.rsc.fastsms", // --dest
+            "/", // destination object path
+            "it.rsc.fastsms", // message name (w/o method)
+            "addRecipient" // method
+            );
+
+    QList<QVariant> args;
+    args.append(number);
+    args.append("NoName");
+    //msg << QString(number);
+    //msg << QString("NoName");
+    //msg << 0;
+    msg.setArguments(args);
+    msg = QDBusConnection::sessionBus().call(msg);
+    bool ok = msg.type() != QDBusMessage::ErrorMessage;
+    qDebug() << msg.errorMessage();
+    if(!ok)
+    {
+        qDebug() << "Error!";
+        QMaemo5InformationBox::information(this, "Install fastSMS to <b>Enable</b> this feature.", QMaemo5InformationBox::DefaultTimeout);
+    }
 }
 
 void horizontalcall::enableButtons()
