@@ -4,10 +4,20 @@
 #include <QtGui>
 #include <QContact>
 #include <QContactPhoneNumber>
+#include <QMessageBox>
+
+//Added for dbus service
+#include <QMainWindow>
+#include <QCloseEvent>
+// ---------------------
 
 #include "contactsthreadworker.h"
 #include "qtmaemo5rotator.h"
 
+#define APP_DBUS_PATH "/com/eitam/horizontalcall"
+#define APP_DBUS_SERVICE "com.eitam.horizontalcall"
+#define APP_DBUS_INTERFACE "com.eitam.horizontalcall"
+
 namespace Ui {
     class horizontalcall;
 }
@@ -15,6 +25,7 @@ namespace Ui {
 class horizontalcall : public QMainWindow
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "com.eitam.horizontalcall")
 
 public slots:
     void clearButtonClicked();
@@ -31,6 +42,7 @@ public slots:
     void AddContact(QtMobility::QContact temp);
     void ContactUpdatesDone();
     void Copy_m_Contacts(QList<QtMobility::QContact>);
+    Q_SCRIPTABLE int top_application();
 
 signals:
 
@@ -43,6 +55,10 @@ protected:
 
 private:
     //Members
+
+    //Added for dbus service
+    void closeEvent(QCloseEvent *event);
+    // ---------------------
     Ui::horizontalcall *ui;
     QtMaemo5Rotator *rotator;
     QList<QPushButton*> *existingLetterButtons;
@@ -122,6 +138,7 @@ private:
     void createLetters();
     void getContactDetails(QString contactName);
     void makeDbusGSMCall(QString number);
+    void sendFastSMS(QString number);
     void showContactDetails(int row);
     void CreateLetter(QString letter);
     void createStyle();
