@@ -2,6 +2,8 @@
 #include "horizontalcall.h"
 #include "contactsthreadworker.h"
 #include "appsettingsmanager.h"
+#include <QDBusConnection>
+#include <QDBusError>
 
 int main(int argc, char *argv[])
 {
@@ -25,5 +27,23 @@ int main(int argc, char *argv[])
     else
         window.showNormal();
 
+    if (!QDBusConnection::sessionBus().isConnected()) {
+        qWarning("Cannot connect to the D-Bus session bus.");
+        exit(1);
+    }
+
+    if (!QDBusConnection::sessionBus().registerService("com.eitam.horizontalcall")) {
+        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().
+            message()));
+        exit(2);
+    }
+
+    if (!QDBusConnection::sessionBus().registerObject("/com/eitam/horizontalcall", &window,
+            QDBusConnection::ExportScriptableSlots)) {
+        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().
+            message()));
+        exit(3);
+    }
+
     return app.exec();
 }
